@@ -15,7 +15,7 @@ use namespace::autoclean;
 extends 'App::Sqitch::Command';
 with 'App::Sqitch::Role::RevertDeployCommand';
 
-our $VERSION = 'v1.1.0'; # VERSION
+our $VERSION = 'v1.2.0'; # VERSION
 
 has onto_change => (
     is  => 'ro',
@@ -81,6 +81,7 @@ sub execute {
     $engine->no_prompt( $self->no_prompt );
     $engine->prompt_accept( $self->prompt_accept );
     $engine->log_only( $self->log_only );
+    $engine->lock_timeout( $self->lock_timeout );
 
     # Revert.
     $engine->set_variables( $self->_collect_revert_vars($target) );
@@ -141,6 +142,11 @@ Change onto which to rebase the target.
 
 Change up to which to rebase the target.
 
+=head3 C<modified>
+
+Boolean to revert to the change prior to earliest change with a revised
+deploy script.
+
 =head2 Instance Methods
 
 =head3 C<execute>
@@ -169,7 +175,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2020 iovation Inc.
+Copyright (c) 2012-2021 iovation Inc., David E. Wheeler
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
