@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 use Moo::Role;
-use App::Sqitch::Types qw(Str Bool HashRef);
+use App::Sqitch::Types qw(Str Int Bool HashRef);
 use Type::Utils qw(enum);
 use namespace::autoclean;
 
@@ -17,7 +17,7 @@ requires 'configure';
 with 'App::Sqitch::Role::ContextCommand';
 with 'App::Sqitch::Role::ConnectingCommand';
 
-our $VERSION = 'v1.1.0'; # VERSION
+our $VERSION = 'v1.2.0'; # VERSION
 
 has target => (
     is  => 'ro',
@@ -36,6 +36,13 @@ has log_only => (
     default  => 0,
 );
 
+has lock_timeout => (
+    is      => 'ro',
+    isa     => Int,
+    lazy    => 1,
+    default => sub { App::Sqitch::Engine::default_lock_timeout() },
+);
+
 has no_prompt => (
     is  => 'ro',
     isa => Bool
@@ -103,6 +110,7 @@ around options => sub {
         set-deploy|e=s%
         set-revert|r=s%
         log-only
+        lock-timeout=i
         y
     );
 };
@@ -112,8 +120,9 @@ around configure => sub {
     my $cmd = $class->command;
 
     my $params = $class->$orig($config, $opt);
-    $params->{log_only} = $opt->{log_only} if $opt->{log_only};
-    $params->{target}   = $opt->{target}   if $opt->{target};
+    for my $key (qw(log_only target lock_timeout)) {
+        $params->{$key} = $opt->{$key} if exists $opt->{$key};
+    }
 
     # Verify?
     $params->{verify} = $opt->{verify}
@@ -204,6 +213,11 @@ Configures the options common to commands that revert and deploy.
 
 Boolean indicating whether to log the deploy without running the scripts.
 
+=head3 C<lock_timeout>
+
+The number of seconds to wait for an exclusive advisory lock on the target,
+for engines that support the feature.
+
 =head3 C<no_prompt>
 
 Boolean indicating whether or not to prompt the user to really go through with
@@ -249,7 +263,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2020 iovation Inc.
+Copyright (c) 2012-2021 iovation Inc., David E. Wheeler
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
